Enabling setting of loglevel in EtchRuntime for default logger

An additional constructor for the EtchRuntime makes it possible now to set
the log level for the default console appender.

Change-Id: I19ab47ca7d6fb941a38e7e952a40ab954efd84f9

git-svn-id: https://svn.apache.org/repos/asf/etch/trunk@1578908 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/binding-cpp/runtime/src/main/support/EtchRuntime.cpp b/binding-cpp/runtime/src/main/support/EtchRuntime.cpp
index d75a0fe..7f41b95 100644
--- a/binding-cpp/runtime/src/main/support/EtchRuntime.cpp
+++ b/binding-cpp/runtime/src/main/support/EtchRuntime.cpp
@@ -32,11 +32,20 @@
   generateRuntimeId();
 }
 
+EtchRuntime::EtchRuntime(EtchLogLevel logLevel)
+  :   mIsClosed(false)
+    , mLogger(mDefaultLogAppender)
+{
+  mLogger.setLogLevel(logLevel);
+
+  //assign a unique id to this runtime
+  generateRuntimeId();
+}
+
 EtchRuntime::EtchRuntime(IEtchLogAppender& logAppender, EtchLogLevel logLevel)
   :   mIsClosed(false)
     , mLogger(logAppender)
 {
-  //Default log level is WARN
   mLogger.setLogLevel(logLevel);
 
   //assign a unique id to this runtime
diff --git a/binding-cpp/runtime/include/support/EtchRuntime.h b/binding-cpp/runtime/include/support/EtchRuntime.h
index 96a1537..c1a7c6c 100644
--- a/binding-cpp/runtime/include/support/EtchRuntime.h
+++ b/binding-cpp/runtime/include/support/EtchRuntime.h
@@ -43,12 +43,19 @@
 
   /**
    * Create a new instance of the EtchRuntime class
    * It uses the default Console Log Appender for logging.
    */
   EtchRuntime();
 
   /**
    * Create a new instance of the EtchRuntime class
+   * It uses the default Console Log Appender for logging with the given log level.
+   * @param logLevel the log level
+   */
+  EtchRuntime(EtchLogLevel logLevel);
+
+  /**
+   * Create a new instance of the EtchRuntime class
    * @param logAppender the log appender
    * @param logLevel the log level
    */
@@ -43,12 +43,19 @@
   /**
    * Create a new instance of the EtchRuntime class
-   * It uses the default Console Log Appender for logging.
+   * It uses the default Console Log Appender for logging with log level WARN.
    */
   EtchRuntime();